@@ -7,7 +7,7 @@
 #   modified 17 December 2008 by Richard Heiberger  ##rmh
 
 Commander <- function(){
-	RcmdrVersion <- "1.6-3"
+	RcmdrVersion <- "1.6-4"
 	##    DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 	##    RcmdrVersion <- trim.blanks(sub("^Version:", "",
 	##        grep("^Version:", D, value=TRUE)))
@@ -614,6 +614,9 @@ Commander <- function(){
 	tkbind(.log, "<ButtonPress-3>", contextMenuLog)
 	tkbind(.output, "<ButtonPress-3>", contextMenuOutput)
 	tkbind(.messages, "<ButtonPress-3>", contextMenuMessages)
+	tkbind(.log, "<Control-ButtonPress-1>", contextMenuLog)
+	tkbind(.output, "<Control-ButtonPress-1>", contextMenuOutput)
+	tkbind(.messages, "<Control-ButtonPress-1>", contextMenuMessages)
 	tkwm.deiconify(.commander)
 	tkfocus(.commander)
 	if (getRcmdr("crisp.dialogs")) tclServiceMode(on=TRUE)
