@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 22 August 2009 by J. Fox
+# last modified 20 November 2010 by J. Fox
 
     # Means menu
 
@@ -190,7 +190,9 @@ singleSampleTTest <- function(){
 					command <- paste(".Pairs <- glht(", modelValue, ", linfct = mcp(", group, ' = "Tukey"))', sep="")
 					justDoIt(command)
 					logger(command)
-					doItAndPrint("confint(.Pairs)")
+					doItAndPrint("summary(.Pairs) # pairwise tests")
+					doItAndPrint("confint(.Pairs) # confidence intervals")
+					doItAndPrint("cld(.Pairs) # compact letter display")
 					justDoIt("old.oma <- par(oma=c(0,5,0,0))")
 					logger("old.oma <- par(oma=c(0,5,0,0))")
 					justDoIt("plot(confint(.Pairs))")
